# Copyright The OpenTelemetry Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import Final

WEBENGINE_DESCRIPTION: Final = "webengine.description"
"""
Additional description of the web engine (e.g. detailed version and edition information).
"""

WEBENGINE_NAME: Final = "webengine.name"
"""
The name of the web engine.
"""

WEBENGINE_VERSION: Final = "webengine.version"
"""
The version of the web engine.
"""
